Index: TVLibrary/TVLibrary/Implementations/DVB/Graphs/DvbBaseScanning.cs
===================================================================
--- TVLibrary/TVLibrary/Implementations/DVB/Graphs/DvbBaseScanning.cs	(revision 27841)
+++ TVLibrary/TVLibrary/Implementations/DVB/Graphs/DvbBaseScanning.cs	(working copy)
@@ -353,7 +353,7 @@
               info.scrambled = (freeCAMode != 0);
               info.network_pmt_PID = pmtPid;
 
-              if (IsKnownServiceType(info.serviceType))
+              if (IsValidChannel(info, hasAudio, hasVideo))
               {
                 if (info.service_name.Length == 0)
                 {
@@ -535,6 +535,11 @@
 
     #region Helpers
 
+    protected virtual bool IsValidChannel(ChannelInfo info, short hasAudio, short hasVideo)
+    {
+      return IsKnownServiceType(info.serviceType);
+    }
+
     protected virtual bool IsKnownServiceType(int serviceType)
     {
       return IsRadioService(serviceType) || IsTvService(serviceType);
Index: TVLibrary/TVLibrary/Implementations/DVB/Graphs/DVBIP/DVBIPScanning.cs
===================================================================
--- TVLibrary/TVLibrary/Implementations/DVB/Graphs/DVBIP/DVBIPScanning.cs	(revision 27841)
+++ TVLibrary/TVLibrary/Implementations/DVB/Graphs/DVBIP/DVBIPScanning.cs	(working copy)
@@ -59,5 +59,23 @@
       Log.Log.Write("Found: {0}", dvbipChannel);
       return dvbipChannel;
     }
+
+    protected override bool IsValidChannel(ChannelInfo info, short hasAudio, short hasVideo)
+    {
+      //In DVB-IP there are several ways to describe a channel. It is possible that no service type is given. 
+      //Until we can fully implement DVB-IP support we check if video or audio is available to determine the channel type.
+      if (info.serviceType <= 0)
+      {
+        if (hasVideo != 0)
+        {
+          info.serviceType = (int)DvbServiceType.DigitalTelevision;
+        }
+        else if (hasAudio != 0)
+        {
+          info.serviceType = (int)DvbServiceType.DigitalRadio;
+        }
+      } 
+      return base.IsValidChannel(info, hasAudio, hasVideo);
+    }
   }
 }
\ No newline at end of file
